@@ -26,7 +26,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.3.10"
+__version__ = "1.3.11"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_INA260.git"
 
 from micropython import const
@@ -186,7 +186,7 @@ class INA260:
 
         if self._device_id != self.INA260_ID:
             raise RuntimeError(
-                "Failed to find INA260 ID, read {self._device_id} while expected {self.INA260_ID}"
+                f"Failed to find INA260 ID, read {self._device_id} while expected {self.INA260_ID}"
                 " - check your wiring!"
             )
 
